==> fd-help-801.2020.08.26-noarch-1.txz: usr/share/doc/fd-help/localize.md <==
![ ](fatdog64.png)
# Foreign languages

Localization is use of regional entities (date, numbers, adress, etc)
**and** language.

Note, before you can choose from languages other than English you must **load** the file for **n**ative **l**anguage **s**upport: fd64-**nls**_xxx.sfs where xxx is the version of Fatdog. Get your version by:

		cat /etc/fatdog-version

## How to use localization

### fd64-nls_xxx.sfs

Get it from Control panel > System > SFS Manager

For Fatdog64-701 get fd64-nls_701.sfs

If you have already got that file in your /aufs/devsave directory it is no more shown in SFS manager.

Use SFS-Loader (from Control panel > System) to load that file **always at boot up**. 


### Choose locale(s)

Choose your locale via Control panel.

If you need more than one locale or just like to play with them, then choose more.

All **available** translations are used for the actual language.

Using the package **quick-locale-switcher** you can switch between **your** chosen locales without need to restart the session.


### Other sources

Large packages have translations of their own, e.g. get seamonkey's native language support from their website.

If you get Google Chrome via 'Control panel > Updates', several translations are already included.

**C**ommon **U**nix **P**rint **S**erver comes with several languages but user has no choice; CUPS does simply use just the browser's language.

**getlibre.sh** will give you choices which language packages for LibreOffice to download.

**update-firefox.sh**  will give you a choice from more than 80 languages for latest Firefox to download and install.

## How to enhance localization

**Goal** is make Fatdog have (nearly) all you need **in one SFS file**. 

... and don't forget to share them, contribute to our goal (see above).

... use package **momanager** from package manager **gslapt**.

### Momanager

Use it to create or edit translation of Fatdog64's scripts, READMEs and help files.

Use it to create or edit translation of **Name** in 'Menu Categories...'.

Use it to create or edit translation of **Name**, **GenericName**, and **Comment** in 'Menu entries...'.

Use momanager (via green button at the bottom) to 'Create a langpackFatdog' for your language.

This langpackFatdog is very different from Puppy's langpacks.

### Where are translated Name, GenericName, Comment being used?

**Name** is displayed in menus of lxqt-panel, openbox and jwm

**GenericName** is displayed in menu of lxqt-panel like: Name (GenericName)

**Comment** is displayed by Rox-Filer if moused over in /usr/share/applications 

Note, there is no need to translate if translation is equal to untranslated term.

---

(Some pictures would be nice, I know ...)

Everyone is a foreigner. Almost anywhere. (Proverb from last century's early seventies)

==> fd-help-899.0-noarch-1.txz: usr/share/doc/fd-help/localize.md <==
![ ](fatdog64.png)
# Foreign languages

Localization is use of regional entities (date, numbers, adress, etc)
**and** language.

Note, before you can choose from languages other than English you must **load** the file for **n**ative **l**anguage **s**upport: fd64-**nls**_xxx.sfs where xxx is the version of Fatdog. Get your version by:

		cat /etc/fatdog-version

## How to use localization

### fd64-nls_xxx.sfs

Get it from Control panel > System > SFS Manager

For Fatdog64-701 get fd64-nls_701.sfs

If you have already got that file in your /aufs/devsave directory it is no more shown in SFS manager.

Use SFS-Loader (from Control panel > System) to load that file **always at boot up**. 


### Choose locale(s)

Choose your locale via Control panel.

If you need more than one locale or just like to play with them, then choose more.

All **available** translations are used for the actual language.

Using the package **quick-locale-switcher** you can switch between **your** chosen locales without need to restart the session.


### Other sources

Large packages have translations of their own, e.g. get seamonkey's native language support from their website.

If you get Google Chrome via 'Control panel > Third-party Software Installers', several translations are already included.

**C**ommon **U**nix **P**rint **S**erver comes with several languages but user has no choice; CUPS does simply use just the browser's language.

**getlibre.sh** will give you choices which language packages for LibreOffice to download.

**update-firefox.sh**  will give you a choice from more than 80 languages for latest Firefox to download and install.

## How to enhance localization

**Goal** is make Fatdog have (nearly) all you need **in one SFS file**. 

... and don't forget to share them, contribute to our goal (see above).

... use package **momanager** from package manager **gslapt**.

### Momanager

Use it to create or edit translation of Fatdog64's scripts, READMEs and help files.

Use it to create or edit translation of **Name** in 'Menu Categories...'.

Use it to create or edit translation of **Name**, **GenericName**, and **Comment** in 'Menu entries...'.

Use momanager (via green button at the bottom) to 'Create a langpackFatdog' for your language.

This langpackFatdog is very different from Puppy's langpacks.

### Where are translated Name, GenericName, Comment being used?

**Name** is displayed in menus of lxqt-panel, openbox and jwm

**GenericName** is displayed in menu of lxqt-panel like: Name (GenericName)

**Comment** is displayed by Rox-Filer if moused over in /usr/share/applications 

Note, there is no need to translate if translation is equal to untranslated term.

---

(Some pictures would be nice, I know ...)

Everyone is a foreigner. Almost anywhere. (Proverb from last century's early seventies)
